@@ -231,7 +231,17 @@ class MediaReview:
 
                         else:
                             params[attribute] = str(value)
-                content = ET.Element(c.__class__.__name__, params)
+                
+                # Test if body characters are accepted, else clean it
+                try:
+                    content = ET.Element(c.__class__.__name__, params)
+                except ValueError:
+                    import string
+
+                    string_to_clean = params.get('body')
+                    printable = set(string.printable)
+                    params['body'] = string_to_clean.encode('utf8', errors='replace').decode('utf8')
+                
                 contents.append(content)
 
             # Set note metadata
