@@ -27,6 +27,8 @@ from xml.dom import minidom
 
 
 class Note:
+    _date = None
+
     def __init__(
         self,
         author: str,
@@ -44,7 +46,11 @@ class Note:
         :param metadata: Note metadata.
         """
         self.author = author
-        self.date = date or datetime.now(timezone.utc).isoformat()
+
+        if date:
+            self.date = date
+        else:
+            self.date = datetime.now(timezone.utc).isoformat()
 
         self.contents = []
         if contents:
@@ -54,6 +60,14 @@ class Note:
 
         self.metadata = metadata or {}
 
+    @property
+    def date(self):
+        return self._date
+
+    @date.setter
+    def date(self, value):
+        self._date = datetime.fromisoformat(value)
+
     def add_content(self, content: Union[Content, List[Content]]):
         """Add content to the note.
         If the content is an Abstract one, a TypeError is raised.
